chin07:
Breast cancer data set of genome-wide copy number merged data and expression of some important genes
Description
A subset of breast cancer data as used in Yuan et al. (to be submitted).
Usage
data(chin07)
Arguments
Format
A list object of two named data matrices, cn: DNA copy number, ge: RNA expression. The matrices columns are samples and rows are probes/variables.
Details
Genome-wide copy number data was merged using CGHregions resulting in 339 regions across 106 samples. Expression data are 7 probes mapped to important breast cancer genes such as CCNE2, MYC, etc, also of 106 samples.
References
Chin SF, Teschendorff AE, Marioni JC, Wang Y, Barbosa-Morais NL, et al. (2007) High-resolution arraycgh and expression profiling identifies a novel genomic subtype of er negative breast cancer. Genome Biology 8: R215+.
Yuan et al. (2011) Discovery and functional annotation of cis- and trans-acting DNA copy
number hotspots in breast cancer, to be submitted.